Quantile

Struct Quantile 

pub struct Quantile<Num, NumArr, UsizeArr>
where Num: Float,
{ /* private fields */ }
Available on crate features libm or std only.
Moving quantile over a sliding window based on partitioning heaps.

Implementations

Source

impl<Num> Quantile<Num, Vec<Num>, Vec<usize>>

pub fn new(probability: Num, window_size: usize) -> Self

Available on crate features alloc or std only.

Create a new quantile tracker with a specific window size.

Arguments
  • probability – Probability of the quantile to compute. For example, 0.5 for the median, or 0.75 for the 75th percentile.
  • window_size – Sliding window size. The target quantile is tracked for this many most recent observations. The algorithm is intended for moderate window sizes of roughly 10 to 10,000 elements.
Panics
  • when window_size is zero
  • when probability is outside 0..=1
Source

impl<Num, const WIN_SIZE: usize> Quantile<Num, [Num; WIN_SIZE], [usize; WIN_SIZE]>

pub fn new(probability: Num) -> Self

Create a new quantile tracker with a specific window size.

Arguments
  • window_size – Sliding window size. The target quantile is tracked for this many most recent observations. The algorithm is intended for moderate window sizes of roughly 10 to 10,000 elements.
  • probability – Probability of the quantile to compute. For example, 0.5 for the median, or 0.75 for the 75th percentile.
Panics
  • when window_size is zero
  • when probability is outside 0..=1
Source

impl<Num, NumArr, UsizeArr> Quantile<Num, NumArr, UsizeArr>
where Num: Float + FromPrimitive + ToPrimitive, NumArr: Index<usize, Output = Num> + IndexMut<usize, Output = Num>, UsizeArr: Index<usize, Output = usize> + IndexMut<usize, Output = usize>,

pub fn add(&mut self, value: Num)

Add an observation and update the quantile estimate.

If the window is full, the oldest observation will be removed.

Arguments
  • value – the next observation in your data stream
pub fn get(&self) -> Num

The target quantile for the last n ≤ window_size observations.

For example, when initialized with probability = 0.2, this returns a value ≥ 20% of the observations in the sliding window, and ≤ 80% of them.

This returns NAN if zero values have been observed so far.